# Extra encodings for Python 
#### Full documentation available at [sites.google.com](https://sites.google.com/view/extra-encodings-docs/)
Final Major Release.
3 months of thinking and work.
Thank you.